@@ -140,7 +140,7 @@ class Worker(object):
 
     def _get_output(self):
         self.output.seek(0, io.SEEK_SET)
-        output = self.output.readall()
+        output = self.output.read()
         self.output.close()
         return output
 
